@@ -27,12 +27,12 @@
   POSSIBILITY OF SUCH DAMAGE.
 */
 
-/* $Id: fdevopen.c,v 1.7 2007/01/23 15:32:48 joerg_wunsch Exp $ */
+/* $Id: fdevopen.c 1944 2009-04-01 23:12:20Z arcanum $ */
 
 #include <stdint.h>
 #include <stdio.h>
 #include <stdlib.h>
-
+#include "sectionname.h"
 #include "stdio_private.h"
 
 /** \file */
@@ -82,6 +82,7 @@
    not use for new code.
 */
 
+ATTRIBUTE_CLIB_SECTION
 FILE *
 fdevopen(int (*put)(char, FILE *), int (*get)(FILE *))
 {
