@@ -31,7 +31,9 @@
 */
 
 /* From: Id: printf_p_new.c,v 1.1.1.9 2002/10/15 20:10:28 joerg_wunsch Exp */
-/* $Id: vfprintf.c 1944 2009-04-01 23:12:20Z arcanum $ */
+/* $Id: vfprintf.c 2553 2021-05-20 21:50:20Z joerg_wunsch $ */
+
+#if !defined(__AVR_TINY__)
 
 #include <avr/pgmspace.h>
 #include <stdarg.h>
@@ -77,7 +79,7 @@
 	"lpm	%0,Z+	\n\t"			\
 	"sbrs	%2,%3	\n\t"			\
 	"ld	%0,Z+	"			\
-	: "=r" (__c),				\
+	: "=&r" (__c),				\
 	  "+z" (pnt)				\
 	: "r" (flag),				\
 	  "I" (ntz(mask))			\
@@ -88,7 +90,6 @@
 # define GETBYTE(flag, mask, pnt)	({	\
     unsigned char __c;				\
     asm (					\
-	"sbrc	%2,%3	\n\t"			\
 	"lpm		\n\t"			\
 	"sbrs	%2,%3	\n\t"			\
 	"ld	r0,Z	\n\t"			\
@@ -217,7 +218,7 @@ vfprintf (FILE * stream, const char *fmt, va_list ap)
 		goto ultoa;
 	      case 'p':
 	        flags |= FL_ALT;
-		/* no break */
+		/* fallthrough */
 	      case 'x':
 		flags |= (FL_ALTHEX | FL_ALTLWR);
 	        base = 16;
@@ -616,7 +617,7 @@ int vfprintf (FILE * stream, const char *fmt, va_list ap)
 		goto ultoa;
 	      case 'p':
 	        flags |= FL_ALT;
-		/* no break */
+		/* fallthrough */
 	      case 'x':
 		if (flags & FL_ALT)
 		    flags |= FL_ALTHEX;
@@ -711,4 +712,7 @@ int vfprintf (FILE * stream, const char *fmt, va_list ap)
   ret:
     return stream->len;
 }
+
 #endif	/* PRINTF_LEVEL > PRINTF_MIN */
+
+#endif /* !defined(__AVR_TINY__) */
