@@ -30,7 +30,9 @@
   POSSIBILITY OF SUCH DAMAGE.
 */
 
-/* $Id: vfscanf.c 1944 2009-04-01 23:12:20Z arcanum $ */
+/* $Id: vfscanf.c 2554 2021-05-20 22:22:24Z joerg_wunsch $ */
+
+#if !defined(__AVR_TINY__)
 
 #include <avr/pgmspace.h>
 #include <ctype.h>
@@ -127,7 +129,7 @@ typedef unsigned char width_t;
 	"lpm	%0,Z+	\n\t"			\
 	"sbrs	%2,%3	\n\t"			\
 	"ld	%0,Z+	"			\
-	: "=r" (__c),				\
+	: "=&r" (__c),				\
 	  "+z" (pnt)				\
 	: "r" (flag),				\
 	  "I" (_FFS(mask) - 1)			\
@@ -138,7 +140,6 @@ typedef unsigned char width_t;
 # define GETBYTE(flag, mask, pnt)	({	\
     unsigned char __c;				\
     asm (					\
-	"sbrc	%2,%3	\n\t"			\
 	"lpm		\n\t"			\
 	"sbrs	%2,%3	\n\t"			\
 	"ld	r0,Z	\n\t"			\
@@ -394,7 +395,7 @@ conv_brk (FILE *stream, width_t width, char *addr, const char *fmt)
    long to float.  Instead it uses a signed long to float conversion
    function along with a large inline code to correct the result.
    Seems, GCC 4.3 does not use it also.	*/
-extern double __floatunsisf (unsigned long);
+extern float __floatunsisf (unsigned long);
 
 PROGMEM static const float pwr_p10 [6] = {
     1e+1, 1e+2, 1e+4, 1e+8, 1e+16, 1e+32
@@ -596,7 +597,7 @@ static int skip_spaces (FILE *stream)
      to <tt>char</tt> (rather than <tt>int</tt>).
    - the character \c l indicating that the argument is a pointer
      to <tt>long int</tt> (rather than <tt>int</tt>, for integer
-     type conversions), or a pointer to \c double (for floating
+     type conversions), or a pointer to \c float (for floating
      point conversions),
 
    In addition, a maximal field width may be specified as a nonzero
@@ -880,3 +881,5 @@ int vfscanf (FILE * stream, const char *fmt, va_list ap)
   eof:
     return nconvs ? nconvs : EOF;
 }
+
+#endif /* !defined(__AVR_TINY__) */
