@@ -26,7 +26,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: asmdef.h 2428 2014-05-01 14:13:18Z amylaar $	*/
+/* $Id: asmdef.h 2473 2015-04-09 08:10:22Z pitchumani $	*/
 
 #ifndef	_ASMDEF_H
 #define _ASMDEF_H
@@ -43,6 +43,16 @@
 # endif
 #endif
 
+/* Define XJMP/XCALL with rjmp/rcall if the arch do not have
+   jmp/call instructions. */
+#if (__AVR_HAVE_JMP_CALL__)
+# define XJMP jmp
+# define XCALL call
+#else
+# define XJMP rjmp
+# define XCALL rcall
+#endif
+
 /* Historicaly, the _U() was intended to concatinate '_' prefix.
    Let us save it, as one is usefull to find externals quickly.	*/
 #define	_U(name)	name
